@@ -21,4 +21,13 @@
         "mastodon-tl--byline-timestamp-has-relative-display"
         "mastodon-tl--next-tab-item--no-spaces-at-ends"
         "mastodon-tl--next-tab-item--with-spaces-at-ends"
+        ;; Known limitation of mock causing the following error:
+        ;;   (epg-error "Encrypt failed" "Exit")
+        "mastodon-auth-plstore-token-check"
+        "mastodon-client--make-user-active"
+        "mastodon-client--store"
+        "mastodon-client--store-access-token"
+        ;; Known issue causing test failure:
+        ;; https://codeberg.org/martianh/mastodon.el/commit/3743eb6299387b26eaae0b76a4f4d2c5fbbb9d03
+        "mastodon-tl--do-user-action-function-follow-notify-block-mute"
         )))
